OC.L10N.register(
    "spreed",
    {
    "a conversation" : "μια συνομιλία",
    "(Duration %s)" : "(Διάρκεια %s)",
    "You attended a call with {user1}" : "Παρακολουθήσατε μια κλήση με {user1}",
    "_%n guest_::_%n guests_" : ["%n επισκέπτης","%n επισκέπτες"],
    "You attended a call with {user1} and {user2}" : "Παρακολουθήσατε μια κλήση με {user1} και {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2} και {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2}, {user3} και {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Παρακολουθήσατε μια κλήση με {user1}, {user2}, {user3}, {user4} και {user5}",
    "_%n other_::_%n others_" : ["%n άλλος","%n άλλοι"],
    "{actor} invited you to {call}" : "Ο {actor} σας προσκάλεσε σε {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Σας προσκάλεσαν για <strong>συζήτηση</strong> ή είχατε μια <strong>κλήση</strong>",
    "Other activities" : "Άλλες δραστηριότητες",
    "Talk" : "Talk",
    "Guest" : "Επισκέπτης",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Το Microsoft Edge και Safari μπορούν να χρησιμοποιηθούν για κλήσεις βίντεο και ήχου",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- Οι συνομιλίες ένας προς ένα είναι σταθερές και δεν μπορούν πλέον να μετατραπούν σε ομαδικές συνομιλίες τυχαία. Επίσης, όταν ένας από τους συμμετέχοντες αποχωρήσει από τη συζήτηση, αυτή δε διαγράφεται αυτόματα πλέον. Μόνο εάν και οι δύο συμμετέχοντες αποχωρήσουν, διαγράφεται από το διακομιστή",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Μπορείτε να ενημερώσετε όλους τους συμμετέχοντες γράφοντας \"@all\" στο chat",
    "- With the \"arrow-up\" key you can repost your last message" : "- Με το \"βελάκι-πάνω\" ξανά γράφεται το τελευταίο μήνυμα",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Το Talk έχει πλέον εντολές, στείλτε \"/help\" σαν μήνυμα στο chat για να δείτε εάν ο διαχειριστής ρύθμισε κάποιες",
    "- With projects you can create quick links between conversations, files and other items" : "- Με τα projects μπορείτε να δημιουργήσετε γρήγορους συνδέσμους μεταξύ συνομιλιών, αρχείων και άλλων αντικειμένων",
    "- You can now mention guests in the chat" : "Μππορείτε πλέον να αναφερθείτε σε επισκέπτες στο chat",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Οι συνομιλίες έχουν πλέον λόμπι. Αυτό επιτρέπει στους συντονιστές να προετοιμαστούν για την συνάντηση, ενώ οι χρήστες και οι επισκέπτες πρέπει να περιμένουν",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "Μπορείτε πλέον να απαντήσετε απευθείας στα μηνύματα άλλων χρηστών δίνοντας άλλο ύφος στον ορισμό των μηνυμάτων",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Η αναζήτηση συζητήσεων και συμμετεχόντων φιλτράρει τις υπάρχουσες συνομιλίες σας, διευκολύνοντας την εύρεση προηγούμενων συνομιλιών",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Τώρα μπορείτε να προσθέσετε προσαρμοσμένες ομάδες χρηστών σε συνομιλίες όταν είναι εγκατεστημένη η εφαρμογή κύκλων",
    "- Check out the new grid and call view" : "- Ελέγξτε τη νέα προβολή πλέγματος και κλήσεων",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Τώρα μπορείτε να ανεβάσετε και να σύρετε αρχεία απευθείας από τη συσκευή σας στη συνομιλία γραπτών μηνυμάτων",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Τα κοινόχρηστα αρχεία ανοίγουν τώρα απευθείας μέσα στον χώρο συνομιλίας με τις εφαρμογές προβολής",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Τώρα μπορείτε να αναζητήσετε συνομιλίες και μηνύματα στην ενοποιημένη αναζήτηση στην επάνω γραμμή.",
    "- Spice up your messages with emojis from the emoji picker" : "- Εμπλουτίστε τα μηνύματά σας με emojis από την επιλογή emoji.",
    "- You can now change your camera and microphone while being in a call" : "- Τώρα μπορείτε να αλλάξετε την κάμερα και το μικρόφωνό σας ενώ βρίσκεστε σε κλήση.",
    "- Raise your hand in a call with the R key" : "Σηκώστε το χέρι σας σε μια κλήση με το πλήκτρο R",
    "Talk updates ✅" : "Ενημερώσεις Talk ✅",
    "{actor} created the conversation" : "Ο {actor} δημιούργησε την συζήτηση",
    "You created the conversation" : "Δημιουργήσατε μια συζήτηση",
    "An administrator created the conversation" : "Ένας διαχειριστής δημιούργησε την συζήτηση",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ο {actor} μετονόμασε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Μετονομάσατε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Ένας διαχειριστής μετονόμασε την συζήτηση από \"%1$s\" σε \"%2$s\"",
    "{actor} removed the description" : "Ο {actor} κατάργησε την περιγραφή",
    "You removed the description" : "Καταργήσατε την περιγραφή",
    "An administrator removed the description" : "Ένας διαχειριστής κατάργησε την περιγραφή",
    "You started a call" : "Ξεκινήσατε μια κλήση",
    "{actor} started a call" : "Ο {actor} ξεκίνησε μια κλήση",
    "Incoming call" : "Εισερχόμενη κλήση",
    "{actor} joined the call" : "Ο {actor} συμμετέχει στην κλήση",
    "You joined the call" : "Συμμετείχατε στην κλήση",
    "{actor} left the call" : "Ο {actor} αποχώρησε από την κλήση",
    "You left the call" : "Αποχωρήσατε από την κλήση",
    "{actor} unlocked the conversation" : "Ο {actor} ξεκλείδωσε την συζήτηση",
    "You unlocked the conversation" : "Ξεκλειδώσατε την συζήτηση",
    "An administrator unlocked the conversation" : "Ένας διαχειριστής ξεκλείδωσε την συζήτηση",
    "{actor} locked the conversation" : "Ο {actor} κλείδωσε την συζήτηση",
    "You locked the conversation" : "Κλειδώσατε την συζήτηση",
    "An administrator locked the conversation" : "Ένας διαχειριστής κλείδωσε την συζήτηση",
    "{actor} limited the conversation to the current participants" : "{actor} περιόρισε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "You limited the conversation to the current participants" : "Περιορίσατε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "An administrator limited the conversation to the current participants" : "Ένας διαχειριστής περιόρισε την συνομιλία στους τρέχοντες συμμετέχοντες",
    "{actor} opened the conversation to registered users" : "{actor} άνοιξε την συνομιλία σε εγγεγραμμένους χρήστες",
    "You opened the conversation to registered users" : "Ανοίξατε την συνομιλία σε εγγεγραμμένους χρήστες",
    "An administrator opened the conversation to registered users" : "Ένας διαχειριστής άνοιξε την συνομιλία για εγγεγραμμένους χρήστες",
    "The conversation is now open to everyone" : "Η συζήτηση είναι πλέον ανοιχτή για όλους",
    "{actor} opened the conversation to everyone" : "Ο {actor} άνοιξε την συζήτηση για όλους",
    "You opened the conversation to everyone" : "Ανοίξατε την συζήτηση για όλους",
    "{actor} restricted the conversation to moderators" : "Ο {actor} περιόρισε την συζήτηση για συντονιστές",
    "You restricted the conversation to moderators" : "Περιορίσατε την συζήτηση για συντονιστές",
    "{actor} allowed guests" : "Ο {actor} επέτρεψε τους επισκέπτες",
    "You allowed guests" : "Επιτρέψατε τους επισκέπτες",
    "An administrator allowed guests" : "Ένας διαχειριστής επέτρεψε τους επισκέπτες",
    "{actor} disallowed guests" : "Ο {actor} απαγόρευσε τους επισκέπτες",
    "You disallowed guests" : "Απαγορέψατε τους επισκέπτες",
    "An administrator disallowed guests" : "Ένας διαχειριστής απαγόρευσε τους επισκέπτες",
    "{actor} set a password" : "Ο {actor} όρισε κωδικό",
    "You set a password" : "Ορίσατε κωδικό",
    "An administrator set a password" : "Ένας διαχειριστής όρισε κωδικό",
    "{actor} removed the password" : "Ο {actor} αφαίρεσε τον κωδικό",
    "You removed the password" : "Αφαιρέσατε τον κωδικό",
    "An administrator removed the password" : "Ένας διαχειριστής αφαίρεσε τον κωδικό",
    "{actor} added {user}" : "Ο {actor} πρόσθεσε τον {user}",
    "You joined the conversation" : "Συνδεθήκατε στην συζήτηση",
    "{actor} joined the conversation" : "Ο {actor} συνδέθηκε στην συζήτηση",
    "You added {user}" : "Προσθέσατε τον {user}",
    "{actor} added you" : "Ο {actor} σας πρόσθεσε",
    "An administrator added you" : "Ένας διαχειριστής σάς πρόσθεσε",
    "An administrator added {user}" : "Ένας διαχειριστής πρόσθεσε τον χρήστη {user}",
    "You left the conversation" : "Αποχωρήσατε από την συζήτηση",
    "{actor} left the conversation" : "Ο {actor} αποχώρησε από την συζήτηση",
    "{actor} removed {user}" : "Ο {actor} αφαίρεσε τον {user}",
    "You removed {user}" : "Αφαιρέσατε τον {user}",
    "{actor} removed you" : "Ο {actor} σας αφαίρεσε",
    "An administrator removed you" : "Ένας διαχειριστής σάς αφαίρεσε",
    "An administrator removed {user}" : "Ένας διαχειριστής αφαίρεσε τον χρήστη {user}",
    "You added group {group}" : "Προσθέσατε την ομάδα {group}",
    "You removed group {group}" : "Αφαιρέσατε την ομάδα {group}",
    "{actor} promoted {user} to moderator" : "Ο {actor} προήγαγε τον {user} σε συντονιστή",
    "You promoted {user} to moderator" : "Προάγατε τον {user} σε συντονιστή",
    "{actor} promoted you to moderator" : "Ο {actor} σας προήγαγε σε συντονιστή",
    "An administrator promoted you to moderator" : "Ένας διαχειριστής σας προήγαγε σε συντονιστή",
    "An administrator promoted {user} to moderator" : "Ένας διαχειριστής προήγαγε τον {user} σε συντονιστή",
    "{actor} demoted {user} from moderator" : "Ο {actor} υποβίβασε τον {user} από συντονιστή",
    "You demoted {user} from moderator" : "Υποβιβάσατε τον {user} από συντονιστή",
    "{actor} demoted you from moderator" : "Ο {actor} σας υποβίβασε από συντονιστή",
    "An administrator demoted you from moderator" : "Ένας διαχειριστής σας υποβίβασε από συντονιστή",
    "An administrator demoted {user} from moderator" : "Ένας διαχειριστής υποβίβασε τον {user} από συντονιστή",
    "{actor} shared a file which is no longer available" : "Ο {actor} διαμοίρασε ένα αρχείο που δεν είναι πλέον διαθέσιμο",
    "You shared a file which is no longer available" : "Διαμοιράσε αρχείο που δεν είναι πλέον διαθέσιμο",
    "{actor} deleted a message" : "{actor} διέγραψε ένα μήνυμα",
    "You deleted a message" : "Διαγράψατε ένα μήνυμα",
    "Message deleted by author" : "Το μήνυμα διαγράφηκε από τον συντάκτη",
    "Message deleted by {actor}" : "Το μήνυμα διαγράφηκε από {actor}",
    "Message deleted by you" : "Το μήνυμα διαγράφηκε από εσάς",
    "Deleted user" : "Διαγραμμένος χρήστης",
    "Administration" : "Διαχείριση",
    "System" : "Συστήματος",
    "%s (guest)" : "%s (επισκέπτης)",
    "Talk conversations" : "Συνομιλίες με Talk",
    "Talk to %s" : "Talk σε %s",
    "File is not shared, or shared but not with the user" : "Το αρχείο δεν είναι κοινόχρηστο, ή δεν μοιράζεται με τον χρήστη",
    "No account available to delete." : "Δεν υπάρχει διαθέσιμος λογαριασμός για διαγραφή.",
    "File is too big" : "Το αρχείο είναι πολύ μεγάλο",
    "Invalid file provided" : "Έχει δοθεί μη έγκυρο αρχείο",
    "Invalid image" : "Μη έγκυρη εικόνα",
    "Unknown filetype" : "Άγνωστος τύπος αρχείου",
    "Talk mentions" : "Αναφορές σε ονόματα του Talk",
    "Say hi to your friends and colleagues!" : "Πείτε γειά σε φίλους και συνεργάτες!",
    "No unread mentions" : "Δεν υπάρχουν μη αναγνωσμένες αναφορές στο όνομά σας",
    "Call in progress" : "Κλήση σε εξέλιξη",
    "You were mentioned" : "Αναφέρθηκε το όνομά σας",
    "Write to conversation" : "Γράψτε στη συνομιλία",
    "Writes event information into a conversation of your choice" : "Γράφει πληροφορίες εκδήλωσης μιας συνομιλίας επιλογής σας",
    "Conversation invitation" : "Πρόσκληση συζήτησης",
    "Description" : "Περιγραφή",
    "You can also dial-in via phone with the following details" : "Μπορείτε επίσης να καλέσετε μέσω τηλεφώνου με τις ακόλουθες λεπτομέρειες.",
    "Dial-in information" : "Πληροφορίες κλήσης",
    "Meeting ID" : "Αναγνωριστικό Meeting ",
    "Your PIN" : "Το PIN σας",
    "Password request: %s" : "Αίτημα κωδικού πρόσβασης: %s",
    "Private conversation" : "Ιδιωτική συνομιλία",
    "Deleted user (%s)" : "Διεγραμένος χρήστης (%s)",
    "Dismiss notification" : "Αποδέσμευση ειδοποίησης",
    "Accept" : "Αποδοχή",
    "Decline" : "Απόρριψη",
    "New message" : "Νέο μήνυμα",
    "Reminder" : "Υπενθύμιση",
    "Notification" : "Ειδοποιήσεις",
    "{user} in {call}" : "Ο {user} είναι σε {call}",
    "Deleted user in {call}" : "Διαγράφηκε ο χρήστης στην {call}",
    "{guest} (guest) in {call}" : "{guest} (επισκέπτης) στην {call}",
    "Guest in {call}" : "Επισκέπτης στην {call}",
    "{user} sent you a private message" : "Ο {user} σας έστειλε προσωπικό μήνυμα",
    "{user} sent a message in conversation {call}" : "Ο {user} έστειλε μήνυμα στην συζήτηση {call}",
    "A deleted user sent a message in conversation {call}" : "Ένας διεγραμένος χρήστης έστειλε μήνυμα στην συνομιλία {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (επισκέπτης) έστειλε μήνυμα στην συζήτηση {call}",
    "A guest sent a message in conversation {call}" : "Ένας επισκέπτης έστειλε μήνυμα σε μια συνομιλία {call}",
    "{user} replied to your private message" : "Ο {user} απάντησε στο προσωπικό μήνυμα σας",
    "{user} replied to your message in conversation {call}" : "Ο {user} απάντησε στο μήνυμά σας στην συζήτηση {call}",
    "A deleted user replied to your message in conversation {call}" : "Ένας διεγραμένος χρήστης απάντησε στο μήνυμά σας στην συζήτηση {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (επισκέπτης) απάντησε στο μήνυμα σας στην συζήτηση {call}",
    "A guest replied to your message in conversation {call}" : "Ένας επισκέπτης απάντησε στο μήνυμα σας στην συζήτηση {call}",
    "{user} mentioned you in a private conversation" : "Ο {user} σας ανέφερε σε προσωπική συζήτηση",
    "{user} mentioned you in conversation {call}" : "Ο {user} σας ανέφερε σε συζήτηση {call}",
    "A deleted user mentioned you in conversation {call}" : "Ένας διεγραμένος χρήστης σας ανέφερε σε συζήτηση {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (επισκέπτης) σας ανεφερε σε συζήτηση {call}",
    "A guest mentioned you in conversation {call}" : "Ένας επισκέπτης σας ανεφερε σε συζήτηση {call}",
    "View chat" : "Εμφάνιση συνομιλίας",
    "{user} invited you to a group conversation: {call}" : "Ο {user} σας προσκάλεσε σε ομαδική κλήση: {call}",
    "Join call" : "Συμμετοχή σε κλήση",
    "Answer call" : "Απάντηση κλήσης",
    "{user} would like to talk with you" : "Ο {user} θα ήθελε να μιλήσει μαζί σας",
    "Call back" : "Επιστροφή κλήσης",
    "You missed a call from {user}" : "Αναπάντητη κλήση από τον {user}",
    "A group call has started in {call}" : "Ξεκίνησε ομαδική κλήση σε {call}",
    "You missed a group call in {call}" : "Αναπάντητη από ομαδική κλήση {call}",
    "{email} is requesting the password to access {file}" : "Αίτηση από το {email} για κωδικό πρόσβασης στο {file}",
    "{email} tried to request the password to access {file}" : "Προσπάθεια αίτησης από το {email} για κωδικό πρόσβασης στο {file}",
    "Someone is requesting the password to access {file}" : "Κάποιος αιτήθηκε κωδικό πρόσβασης για το {file}",
    "Someone tried to request the password to access {file}" : "Κάποιος προσπαθεί να αιτηθεί κωδικό πρόσβασης για το {file}",
    "Open settings" : "Άνοιγμα ρυθμίσεων",
    "The hosted signaling server is now configured and will be used." : "Ο φιλοξενούμενος διακομιστής σηματοδότησης έχει πλέον ρυθμιστεί και θα χρησιμοποιηθεί.",
    "The hosted signaling server was removed and will not be used anymore." : "Ο φιλοξενούμενος διακομιστής σηματοδότησης καταργήθηκε και δεν θα χρησιμοποιείται πλέον.",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Ο λογαριασμός του φιλοξενούμενου διακομιστή σηματοδότησης άλλαξε την κατάσταση από \"{oldstatus}\" σε \"{newstatus}\".",
    "error" : "σφάλμα ",
    "Open Talk" : "Άνοιγμα του Talk",
    "Conversations" : "Συνομιλίες",
    "{user}" : "{user}",
    "Messages" : "Μηνύματα",
    "{user} in {conversation}" : "Υπάρχουν {user} στην συνομιλία {conversation}",
    "Messages in other conversations" : "Μηνύματα σε άλλες συνομιλίες",
    "Avatar image is not square" : "Η εικόνα του άβαταρ δεν είναι τετράγωνη",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Η αίτηση για δοκιμή απέτυχε επειδή δεν ήταν δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Υπάρχει πρόβλημα με τον έλεγχο ταυτότητας αυτής της περίπτωσης. Ίσως δεν είναι προσβάσιμο από έξω για την επαλήθευση της διεύθυνσης URL του.",
    "Something unexpected happened." : "Κάτι απροσδόκητο συνέβη.",
    "The URL is invalid." : "Η διεύθυνση URL δεν είναι έγκυρη.",
    "An HTTPS URL is required." : "Απαιτείται διεύθυνση URL HTTPS.",
    "The email address is invalid." : "Η διεύθυνση ηλεκτρονικού ταχυδρομείου δεν είναι έγκυρη.",
    "The language is invalid." : "Η γλώσσα δεν είναι έγκυρη.",
    "The country is invalid." : "Η χώρα δεν είναι έγκυρη.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Υπάρχει πρόβλημα με το αίτημα της δοκιμής. Ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "Too many requests are send from your servers address. Please try again later." : "Στέλνονται πάρα πολλά αιτήματα από τη διεύθυνση των διακομιστών σας. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "There is already a trial registered for this Nextcloud instance." : "Υπάρχει ήδη μια δοκιμαστική καταχώριση για αυτήν την περίπτωση του Nextcloud.",
    "Something unexpected happened. Please try again later." : "Κάτι απροσδόκητο συνέβη. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Η αίτηση για δοκιμή απέτυχε επειδή ο διακομιστής δοκιμής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Trial requested but failed to get account information. Please check back later." : "Ζητήθηκε δοκιμή αλλά απέτυχε να λάβει πληροφορίες λογαριασμού. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Υπάρχει πρόβλημα με τον έλεγχο ταυτότητας αυτού του αιτήματος. Ίσως δεν είναι προσβάσιμο από έξω για την επαλήθευση της διεύθυνσης URL του.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Η ανάκτησης πληροφοριών λογαριασμού απέτυχε επειδή ο δοκιμαστικός διακομιστής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Υπάρχει πρόβλημα με την ανάκτηση των πληροφοριών λογαριασμού. Παρακαλούμε ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "There is no such account registered." : "Δεν έχει καταχωρηθεί τέτοιος λογαριασμός.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Η ανάκτηση πληροφοριών λογαριασμού απέτυχε επειδή δεν είναι δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Η διαγραφή του λογαριασμού του φιλοξενούμενου διακομιστή σηματοδότησης απέτυχε. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Η διαγραφής του λογαριασμού απέτυχε επειδή ο δοκιμαστικός διακομιστής συμπεριφέρθηκε εσφαλμένα. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Υπάρχει πρόβλημα με τη διαγραφή του λογαριασμού. Παρακαλούμε ελέγξτε τα αρχεία καταγραφής σας για περισσότερες πληροφορίες.",
    "Too many requests are sent from your servers address. Please try again later." : "Πάρα πολλά αιτήματα αποστέλλονται από τη διεύθυνση των διακομιστών σας. Παρακαλώ προσπαθήστε ξανά αργότερα.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Η διαγραφής του λογαριασμού απέτυχε επειδή δεν είναι δυνατή η πρόσβαση στον δοκιμαστικό διακομιστή. Παρακαλούμε ελέγξτε ξανά αργότερα.",
    "Andorra" : "Ανδόρα",
    "United Arab Emirates" : "Ηνωμένα Αραβικά Εμιράτα",
    "Afghanistan" : "Αφγανιστάν",
    "Antigua and Barbuda" : "Αντίκουα και Μπαρμπούντα",
    "Anguilla" : "Anguilla",
    "Albania" : "Αλβανία",
    "Armenia" : "Αρμενία",
    "Angola" : "Αγκόλα",
    "Antarctica" : "Ανταρκτική",
    "Argentina" : "Αργεντινή",
    "American Samoa" : "Αμερικανική Σαμόα",
    "Austria" : "Αυστρία",
    "Australia" : "Αυστραλία",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland Islands",
    "Azerbaijan" : "Αζερμπαϊτζάν",
    "Bosnia and Herzegovina" : "Βοσνία και Ερζεγοβίνη",
    "Barbados" : "Μπαρμπάντος",
    "Bangladesh" : "Μπαγκλαντές ",
    "Belgium" : "Βέλγιο",
    "Burkina Faso" : "Μπουρκίνα Φάσο",
    "Bulgaria" : "Βουλγαρία",
    "Bahrain" : "Μπαχρέιν",
    "Burundi" : "Μπουρούντι",
    "Benin" : "Μπενίν",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Βερμούδα",
    "Brunei Darussalam" : "Brunei Darussalam",
    "Bolivia, Plurinational State of" : "Βολιβία, πολυεθνική πολιτεία της",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius and Saba",
    "Brazil" : "Βραζιλία",
    "Bahamas" : "Μπαχάμες",
    "Bhutan" : "Μπουτάν",
    "Bouvet Island" : "Bouvet Island",
    "Botswana" : "Μποτσουάνα",
    "Belarus" : "Λευκορωσία",
    "Belize" : "Μπελίσε",
    "Canada" : "Καναδάς",
    "Cocos (Keeling) Islands" : "Cocos (Keeling) Islands",
    "Congo, the Democratic Republic of the" : "Κονγκό, Λαϊκή Δημοκρατία του ",
    "Central African Republic" : "Δημοκρατία Κεντρικής Αφρικής",
    "Congo" : "Κονγκό",
    "Switzerland" : "Ελβετία",
    "Côte d'Ivoire" : "Côte d'Ivoire",
    "Cook Islands" : "Cook Islands",
    "Chile" : "Χιλή",
    "Cameroon" : "Καμερούν",
    "China" : "Κίνα",
    "Colombia" : "Κολομβία",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Κούβα",
    "Cabo Verde" : "Cabo Verde",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Νησί των Χριστουγέννων\n \n ",
    "Cyprus" : "Κύπρος",
    "Czechia" : "Czechia",
    "Germany" : "Γερμανία",
    "Djibouti" : "Djibouti",
    "Denmark" : "Δανία",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominican Republic",
    "Algeria" : "Αλγερία",
    "Ecuador" : "Εκουαδόρ",
    "Estonia" : "Εσθονία",
    "Egypt" : "Αίγυπτος",
    "Western Sahara" : "Δυτική Σαχάρα",
    "Eritrea" : "Eritrea",
    "Spain" : "Ισπανία",
    "Ethiopia" : "Αιθιοπία",
    "Finland" : "Φινλανδία",
    "Fiji" : "Φίτζι",
    "Falkland Islands (Malvinas)" : "Falkland Islands (Malvinas)",
    "Micronesia, Federated States of" : "Μικρονησία, Ομοσπονδιακά κράτη του",
    "Faroe Islands" : "Νησιά Φερόε",
    "France" : "Γαλλία",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Ηνωμένο Βασίλειο της Μεγάλης Βρετανίας και Βορείου Ιρλανδίας",
    "Grenada" : "Γρενάδα",
    "Georgia" : "Georgia",
    "French Guiana" : "French Guiana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Greenland",
    "Gambia" : "Γκάμπια",
    "Guinea" : "Γουϊνέα",
    "Guadeloupe" : "Γουαδελούπη",
    "Equatorial Guinea" : "Equatorial Guinea",
    "Greece" : "Ελλάδα",
    "South Georgia and the South Sandwich Islands" : "South Georgia and the South Sandwich Islands",
    "Guatemala" : "Γουατεμάλα",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard Island and McDonald Islands",
    "Honduras" : "Honduras",
    "Croatia" : "Κροατία",
    "Haiti" : "Haiti",
    "Hungary" : "Ουγγαρία",
    "Indonesia" : "Ινδονησία",
    "Ireland" : "Ιρλανδία",
    "Israel" : "Ισραήλ",
    "Isle of Man" : "Isle of Man",
    "India" : "Ινδία",
    "British Indian Ocean Territory" : "British Indian Ocean Territory",
    "Iraq" : "Ιράκ",
    "Iran, Islamic Republic of" : "Ιράν, Ισλαμική Δημοκρατία του",
    "Iceland" : "Ισλανδία",
    "Italy" : "Ιταλία",
    "Jersey" : "Jersey",
    "Jamaica" : "Τζαμάικα",
    "Jordan" : "Ιορδανία",
    "Japan" : "Ιαπωνία",
    "Kenya" : "Κένυα",
    "Kyrgyzstan" : "Kyrgyzstan",
    "Cambodia" : "Cambodia",
    "Kiribati" : "Kiribati",
    "Comoros" : "Comoros",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Κορέα, Λαϊκή Δημοκρατία της",
    "Korea, Republic of" : "Δημοκρατία της Κορέας",
    "Kuwait" : "κουβέιτ",
    "Cayman Islands" : "Cayman Islands",
    "Kazakhstan" : "Καζακστάν",
    "Lao People's Democratic Republic" : "Λαϊκή Δημοκρατία του Λάος",
    "Lebanon" : "Λίβανος",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Λιχτενστάιν",
    "Sri Lanka" : "Σρι Λάνκα",
    "Liberia" : "Λιβερία",
    "Lesotho" : "Λεσότο",
    "Lithuania" : "Λιθουανία",
    "Luxembourg" : "Λουξεμβούργο",
    "Latvia" : "Λετονία",
    "Libya" : "Λιβύη",
    "Morocco" : "Μαρόκο",
    "Monaco" : "Μονακό",
    "Moldova, Republic of" : "Δημοκρατία της Μολδαβίας",
    "Montenegro" : "Μαυροβούνιο",
    "Saint Martin (French part)" : "Saint Martin (French part)",
    "Madagascar" : "Μαδαγασκάρη",
    "Marshall Islands" : "Marshall Islands",
    "North Macedonia" : "Δημοκρατία της Βόρειας Μακεδονίας",
    "Mali" : "Μάλι",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Μογγολία",
    "Macao" : "Μακάο",
    "Northern Mariana Islands" : "Northern Mariana Islands",
    "Martinique" : "Μαρτινίκα",
    "Mauritania" : "Μαυριτανία",
    "Montserrat" : "Montserrat",
    "Malta" : "Μάλτα",
    "Mauritius" : "Μαυρίκιος",
    "Maldives" : "Μαλδίβες",
    "Malawi" : "Μαλάουι",
    "Mexico" : "Μεξικό",
    "Malaysia" : "Μαλαισία",
    "Mozambique" : "Μοζαμβίκη",
    "Namibia" : "Ναμίμπια",
    "New Caledonia" : "New Caledonia",
    "Niger" : "Νίγηρα",
    "Norfolk Island" : "Norfolk Island",
    "Nigeria" : "Νιγηρία",
    "Nicaragua" : "Νικαράγουα",
    "Netherlands" : "Ολλανδία",
    "Norway" : "Νορβηγία",
    "Nepal" : "Νεπάλ",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Νέα Ζηλανδία",
    "Oman" : "Ομάν",
    "Panama" : "Παναμάς",
    "Peru" : "Περού",
    "French Polynesia" : "Γαλλική Πολυνησία",
    "Papua New Guinea" : "Παπούα Νέα Γουινέα",
    "Philippines" : "Φιλιππίνες",
    "Pakistan" : "Πακιστάν",
    "Poland" : "Πολωνία",
    "Saint Pierre and Miquelon" : "Saint Pierre and Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Πόρτο Ρίκο",
    "Palestine, State of" : "Παλαιστίνη, Κράτος της",
    "Portugal" : "Πορτογαλία",
    "Palau" : "Palau",
    "Paraguay" : "Παραγουάη",
    "Qatar" : "Κατάρ",
    "Réunion" : "Réunion",
    "Romania" : "Ρουμανία",
    "Serbia" : "Σερβία",
    "Russian Federation" : "Russian Federation",
    "Rwanda" : "Ρουάντα",
    "Saudi Arabia" : "Σαουδική Αραβία",
    "Solomon Islands" : "Νησιά Σολομώντα",
    "Seychelles" : "Σεϊχέλες",
    "Sudan" : "Σουδάν",
    "Sweden" : "Σουηδία",
    "Singapore" : "Σιγκαπούρη",
    "Saint Helena, Ascension and Tristan da Cunha" : "Saint Helena, Ascension and Tristan da Cunha",
    "Slovenia" : "Σλοβενία",
    "Svalbard and Jan Mayen" : "Svalbard and Jan Mayen",
    "Slovakia" : "Σλοβακία",
    "Sierra Leone" : "Σιέρα Λεόνε",
    "San Marino" : "Σαν Μαρίνο",
    "Senegal" : "Σενεγάλη",
    "Somalia" : "Σομαλία",
    "Suriname" : "Σουρινάμ",
    "South Sudan" : "Νότιο Σουδάν",
    "Sao Tome and Principe" : "Sao Tome and Principe",
    "El Salvador" : "Ελ Σαλβαδόρ",
    "Sint Maarten (Dutch part)" : "Sint Maarten (Dutch part)",
    "Syrian Arab Republic" : "Syrian Arab Republic",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks and Caicos Islands",
    "Chad" : "Chad",
    "French Southern Territories" : "Γαλλικά νότια εδάφη",
    "Togo" : "Togo",
    "Thailand" : "Ταϊλάνδη",
    "Tajikistan" : "Tajikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Timor-Leste",
    "Turkmenistan" : "Τουρκμενιστάν",
    "Tunisia" : "Τυνησία",
    "Tonga" : "Tonga",
    "Turkey" : "Τουρκία",
    "Trinidad and Tobago" : "Trinidad and Tobago",
    "Tuvalu" : "Τουβάλου",
    "Taiwan, Province of China" : "Ταϊβάν, επαρχία της Κίνας",
    "Tanzania, United Republic of" : "Tanzania, United Republic of",
    "Ukraine" : "Ουκρανία",
    "Uganda" : "Ουγκάντα",
    "United States Minor Outlying Islands" : "United States Minor Outlying Islands",
    "United States of America" : "United States of America",
    "Uruguay" : "Ουρουγουάη",
    "Uzbekistan" : "Uzbekistan",
    "Holy See" : "Holy See",
    "Saint Vincent and the Grenadines" : "Saint Vincent and the Grenadines",
    "Venezuela, Bolivarian Republic of" : "Βενεζουέλα, Δημοκρατία της Βολιβίας της",
    "Virgin Islands, British" : "Παρθένοι Νήσοι, Βρετανικοί",
    "Virgin Islands, U.S." : "Παρθένοι Νήσοι, ΗΠΑ",
    "Viet Nam" : "Βιετνάμ",
    "Vanuatu" : "Βανουάτου",
    "Wallis and Futuna" : "Wallis and Futuna",
    "Samoa" : "Σαμόα",
    "Yemen" : "Υεμένη",
    "Mayotte" : "Mayotte",
    "South Africa" : "Νότιος Αφρική",
    "Zambia" : "Ζάμπια",
    "Zimbabwe" : "Ζιμπάμπουε",
    "Federation" : "Federation",
    "High-performance backend" : "Backend υψηλής απόδοσης",
    "Error: Cannot connect to server" : "Σφάλμα: Αδυναμία σύνδεσης στο διακομιστή",
    "Error: Server did not respond with proper JSON" : "Σφάλμα: Ο διακομιστής ανταποκρίθηκε με λάθος JSON",
    "Error: Server responded with: {error}" : "Σφάλμα: Ο διακομιστής απάντησε με: {error}",
    "Error: Unknown error occurred" : "Σφάλμα: Παρουσιάστηκε άγνωστο σφάλμα",
    "SIP configuration" : "Διαμόρφωση SIP",
    "Invalid date, date format must be YYYY-MM-DD" : "Μη έγκυρη ημερομηνία, η μορφή της ημερομηνίας πρέπει να είναι YYYY-MM-DD",
    "Conversation not found" : "Η συζήτηση δεν βρέθηκε",
    "Chat, video & audio-conferencing using WebRTC" : "Το Chat, video & ήχο-διάσκεψη χρησιμοποιούν το WebRTC",
    "Leave call" : "Αποχώρηση από την κλήση",
    "Navigating away from the page will leave the call in {conversation}" : "Η απομάκρυνση από την σελίδα θα αφήσει την κλήση σε {conversation}",
    "Stay in call" : "Παραμονή σε κλήση",
    "Discuss this file" : "Συζήτηση γι αυτό το αρχείο",
    "Share this file with others to discuss it" : "Κοινή χρήση του αρχείου για σχολιασμό του",
    "Share this file" : "Κοινή χρήση του αρχείου",
    "Join conversation" : "Συμμετοχή στη συνομιλία",
    "Request password" : "Αίτηση κωδικού πρόσβασης",
    "Error requesting the password." : ".Σφάλμα αίτησης κωδικού πρόσβασης.",
    "This conversation has ended" : "Η συνομιλία τερματίστηκε",
    "Everyone" : "Όλοι",
    "Users and moderators" : "Χρήστες και συντονιστές",
    "Moderators only" : "Συντονιστές μόνο",
    "Save changes" : "Αποθήκευση αλλαγών",
    "Saving …" : "Αποθηκεύεται ...",
    "Saved!" : "Αποθηκεύτηκε!",
    "Limit to groups" : "Περιορισμός σε ομάδες",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Όταν επιλεγεί μία ομάδα, μόνο τα μέλη της μπορούν να συμμετέχουν.",
    "Guests can still join public conversations." : "Οι επισκέπτες μπορούν ακόμη να συμμετέχουν σε συνομιλίες.",
    "Limit using Talk" : "Περιορισμός χρήσης του Talk",
    "Limit creating a public and group conversation" : "Περιορισμός δημιουργίας δημόσιων και ομαδικών συζητήσεων",
    "Limit creating conversations" : "Περιορισμός δημιουργίας συζητήσεων",
    "Limit starting a call" : "Περιορισμός έναρξης κλήσης",
    "Limit starting calls" : "Περιορισμός έναρξης κλήσεων",
    "When a call has started, everyone with access to the conversation can join the call." : "Όταν ξεκινήση μια κλήση, οποισδήποτε με πρόσβαση στην συνομιλία μπορεί να συμμετέχει στην κλήση.",
    "Enabled" : "Ενεργοποιημένο",
    "Disabled" : "Απενεργοποιημένο",
    "State" : "Κατάσταση",
    "Name" : "Όνομα",
    "Beta" : "Δοκιμαστικό",
    "Permissions" : "Δικαιώματα",
    "All messages" : "Όλα τα μηνύματα",
    "@-mentions only" : "@-mentions μόνο",
    "Off" : "Απενεργοποίηση ",
    "General settings" : "Γενικές ρυθμίσεις",
    "Default notification settings" : "Προεπιλεγμένες ρυθμίσεις ειδοποιήσεων",
    "Default group notification" : "Προεπιλεγμένη ομάδα ειδοποιήσεων",
    "Default group notification for new groups" : "Προεπιλεγμένη ομάδα ειδοποιήσεων για νέες ομάδες",
    "Integration into other apps" : "Ενσωμάτωση σε άλλες εφαρμογές",
    "Allow conversations on files" : "Να επιτρέπονται συζητήσεις σε αρχεία",
    "Allow conversations on public shares for files" : "Να επιτρέπονται συνομιλίες για δημόσια διαμοιρασμένα αρχεία",
    "Enable encryption" : "Ενεργοποίηση κρυπτογράφησης",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Κάνοντας κλικ στο κουμπί πάνω από τις πληροφορίες στη φόρμα γίνεται αποστολή στους διακομιστές της Struktur AG. Μπορείτε να βρείτε περισσότερες πληροφορίες στη διεύθυνση {linkstart}spreed.eu{linkend}.",
    "Pending" : "Εκκρεμεί",
    "Error" : "Σφάλμα",
    "Blocked" : "Αποκλεισμένος",
    "Active" : "Ενεργό",
    "Expired" : "Έληξε",
    "Never" : "Ποτέ",
    "The trial could not be requested. Please try again later." : "Δεν ήταν δυνατή η αίτηση της δοκιμής. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "The account could not be deleted. Please try again later." : "Δεν ήταν δυνατή η διαγραφή του λογαριασμού. Παρακαλούμε δοκιμάστε ξανά αργότερα.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Ο συνεργάτης μας Struktur AG παρέχει μια υπηρεσία όπου μπορεί να ζητηθεί ένας φιλοξενούμενος διακομιστής σηματοδότησης. Για αυτό πρέπει να συμπληρώσετε μόνο την παρακάτω φόρμα και το Nextcloud θα το ζητήσει. Μόλις ο διακομιστής ρυθμιστεί για εσάς, τα διαπιστευτήρια θα συμπληρωθούν αυτόματα. Αυτό θα αντικαταστήσει τις υπάρχουσες ρυθμίσεις διακομιστή σηματοδότησης.",
    "URL of this Nextcloud instance" : "Διεύθυνση URL αυτής της περίπτωσης Nextcloud",
    "Full name of the user requesting the trial" : "Πλήρες όνομα του χρήστη που αιτείται την δοκιμή",
    "Email of the user" : "Το email του χρήστη",
    "Language" : "Γλώσσα",
    "Country" : "Χώρα",
    "Request signaling server trial" : "Αίτηση δοκιμής διακομιστή σηματοδότησης",
    "You can see the current status of your hosted signaling server in the following table." : "Μπορείτε να δείτε την τρέχουσα κατάσταση του φιλοξενούμενου διακομιστή σηματοδότησης σας στον παρακάτω πίνακα.",
    "Status" : "Κατάσταση",
    "Created at" : "Έχει δημιουργηθεί στις",
    "Expires at" : "Λήγει στις",
    "Limits" : "Όρια",
    "Yes" : "Ναι",
    "No" : "Όχι",
    "Delete the signaling server account" : "Διαγραφή του λογαριασμού διακομιστή σηματοδότησης",
    "_%n user_::_%n users_" : ["%n χρήστης","%n χρήστες"],
    "Installed version: {version}" : "Εγκατεστημένη έκδοση: {version}",
    "Matterbridge binary was not found or couldn't be executed." : "Το δυαδικό Matterbridge δεν βρέθηκε ή δεν ήταν δυνατό να εκτελεστεί.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Μπορείτε επίσης να ορίσετε τη διαδρομή προς το δυαδικό Matterbridge χειροκίνητα μέσω του config. Ανατρέξτε στην {linkstart} τεκμηρίωση ενσωμάτωσης Matterbridge {linkend} για περισσότερες πληροφορίες.",
    "Downloading …" : "Γίνεται λήψη ...",
    "Install Talk Matterbridge" : "Εγκατάσταση του Talk Matterbridge",
    "An error occurred while installing the Talk Matterbridge. Please install it manually" : "Παρουσιάστηκε σφάλμα κατά την εγκατάσταση της εφαρμογής Talk Matterbridge.Παρακαλούμε εγκαταστήστε την χειροκίνητα.",
    "Failed to execute Matterbridge binary." : "Η εκτέλεση του αλγόριθμου του Matterbridge επέτυχε.",
    "Matterbridge integration" : "Ενσωμάτωση του Matterbridge",
    "Enable Matterbridge integration" : "Ενεργοποίηση της ενσωμάτωσης του Matterbridge",
    "Status: Checking connection" : "Κατάσταση: Έλεγχος σύνδεσης",
    "OK: Running version: {version}" : "OK: Τρέχουσα έκδοση: {version}",
    "Validate SSL certificate" : "Επικυρώστε το πιστοποιητικό SSL",
    "Delete this server" : "Διαγραφή διακομιστή",
    "Test this server" : "Δοκιμή αυτού του διακομιστή",
    "Shared secret" : "Διαμοιρασμένο μυστικό",
    "Restrict SIP configuration" : "Περιορίστε τη διαμόρφωση SIP",
    "Enable SIP configuration" : "Ενεργοποίηση διαμόρφωσης SIP",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Μόνο οι χρήστες των ακόλουθων ομάδων μπορούν να ενεργοποιήσουν το SIP σε συνομιλίες που εποπτεύουν.",
    "Phone number (Country)" : "Αριθμός τηλεφώνου (Χώρα)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Αυτές οι πληροφορίες αποστέλλονται σε email πρόσκλησης καθώς και παρουσιάζονται στην πλευρική γραμμή σε όλους τους συμμετέχοντες.",
    "Error code" : "Σφάλμα κωδικού",
    "High-performance backend URL" : "Διεύθυνση URL backend υψηλής απόδοσης",
    "STUN server URL" : "URL διακομιστή STUN",
    "STUN servers" : "Διακομιστές STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "Ένας διακομιστής STUN χρησιμοποιείται για τον καθορισμό της δημόσιας διεύθυνσης IP των συμμετεχόντων πίσω από ένα δρομολογητή.",
    "{option1} and {option2}" : "{option1} και {option2}",
    "{option} only" : "μόνο {option}",
    "OK: Successful ICE candidates returned by the TURN server" : "ΟΚ: Επιτυχής ανταλλαγή πληροφοριών ICE από τον διακομιστή TURN",
    "Error: No working ICE candidates returned by the TURN server" : "Σφάλμα: Μη επιτυχής ανταλλαγή πληροφοριών ICE από τον διακομιστή TURN",
    "Testing whether the TURN server returns ICE candidates" : "Δοκιμή ασχέτως εάν ο διακομιστής TURN παρέχει πληροφορίες ICE",
    "TURN server URL" : "URL διακομιστή TURN",
    "TURN server secret" : "Μυστικό του διακομιστή TURN",
    "TURN server protocols" : "Πρωτόκολλα διακομιστή TURN",
    "TURN servers" : "Διακομιστές TURN",
    "Failed" : "Απέτυχε",
    "OK" : "OK",
    "Checking …" : "Έλεγχος ...",
    "Federated user" : "Ομοσπονδιακός χρήστης",
    "Create rooms" : "Δημιουργία δωματίων",
    "Confirm" : "Επιβεβαίωση",
    "Reset" : "Επαναφορά",
    "Back" : "Πίσω",
    "Cancel" : "Ακύρωση",
    "Add participant \"{user}\"" : "Προσθήκη συμμετέχοντος \"{user}\"",
    "Now" : "Τώρα",
    "Loading …" : "Φόρτωση…",
    "From" : "Από",
    "To" : "Έως",
    "Calendar" : "Ημερολόγιο",
    "Attendees" : "Συμμετέχοντες",
    "Save" : "Αποθήκευση",
    "Search participants" : "Αναζήτηση συμμετεχόντων",
    "No results" : "Κανένα αποτέλεσμα",
    "Done" : "Ολοκληρώθηκε",
    "Raise hand" : "Σηκώστε το χέρι",
    "Raise hand (R)" : "Σηκώστε το χέρι (R)",
    "Lower hand" : "Κατεβάστε το χέρι",
    "Exit full screen (F)" : "Έξοδος από πλήρη οθόνη (F)",
    "Full screen (F)" : "Πλήρης οθόνη (F)",
    "Speaker view" : "Προβολή ομιλητή",
    "Grid view" : "Προβολή πλέγματος",
    "This conversation is read-only" : "Αυτή η συνομιλία είναι μόνο για ανάγνωση",
    "{nickName} raised their hand." : "Ο {nickName} σήκωσε το χέρι του.",
    "A participant raised their hand." : "Ένας συμμετέχων σήκωσε το χέρι του.",
    "Collapse stripe" : "Σύμπτυξη λωρίδας",
    "Expand stripe" : "Ανάπτυξη λωρίδας",
    "Previous page of videos" : "Προηγούμενη σελίδα βίντεο",
    "Next page of videos" : "Επόμενη σελίδα βίντεο",
    "Connecting …" : "Σύνδεση ...",
    "Waiting for others to join the call …" : "Αναμονή για είσοδο υπόλοιπων στην κλήση ...",
    "You can invite others in the participant tab of the sidebar" : "Μπορείτε να προσκαλέσετε άλλους από την καρτέλα συμμετεχόντων της πλευρικής μπάρας",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Μπορείτε να προσκαλέσετε άλλους από την καρτέλα συμμετεχόντων της πλευρικής μπάρας ή κοινοποιήστε τον σύνδεσμο για πρόσκληση και άλλων!",
    "Share this link to invite others!" : "Διαμοιρασμός του συνδέσμου για να προσκαλέσετε άλλους!",
    "Copy link" : "Αντιγραφή συνδέσμου",
    "Mute audio" : "Σίγαση ήχου",
    "Unmute audio" : "Ενεργοποίηση ήχου",
    "None" : "Κανένα",
    "Access to camera was denied" : "Δεν επιτρέπεται η πρόσβαση στην κάμερα",
    "Error while accessing camera: It is likely in use by another program" : "Σφάλμα κατά την πρόσβαση στην κάμερα: Είναι πιθανό να χρησιμοποιείται από άλλο πρόγραμμα",
    "Error while accessing camera" : "Σφάλμα κατά την πρόσβαση στην κάμερα",
    "You have been muted by a moderator" : "Έγινε σιγή από τον συντονιστή",
    "Disable video" : "Απενεργοποίηση βίντεο",
    "Disable video (V)" : "Απενεργοποίηση βίντεο (V)",
    "Enable video" : "Ενεργοποίηση βίντεο",
    "Enable video (V)" : "Ενεργοποίηση βίντεο (V)",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Ενεργοποίηση βίντεο. Θα γίνει σύντομη διακοπή σύνδεσης κατά την ενεργοποίηση του βίντεο για πρώτη φορά",
    "You" : "Εσείς",
    "Mute" : "Σιγή",
    "Show screen" : "Εμφάνιση οθόνης",
    "Stop following" : "Διακοπή ακολούθησης",
    "Collapse" : "Σύμπτυξη",
    "Expand" : "Επεκτείνω",
    "You need to be logged in to upload files" : "Πρέπει είστε σε σύνδεση για ανέβασμα αρχείων",
    "Drop your files to upload" : "Αποθέστε τα αρχεία σας για ανέβασμα",
    "Conversation messages" : "Μηνύματα συνομιλίας",
    "Scroll to bottom" : "Μετακινηθείτε προς τα κάτω",
    "Post message" : "Δημοσίευση μηνύματος",
    "Favorite" : "Προσθήκη στα αγαπημένα",
    "Date:" : "Ημερομηνία:",
    "Note:" : "Σημείωση:",
    "Hide details" : "Απόκρυψη λεπτομερειών",
    "Show details" : "Εμφάνιση λεπτομερειών",
    "Error while updating conversation description" : "Σφάλμα κατά την ενημέρωση της περιγραφής συνομιλίας",
    "Edit conversation description" : "Επεξεργασία περιγραφής συνομιλίας",
    "Enter a description for this conversation" : "Πληκτρολογήστε μια περιγραφή για αυτήν τη συνομιλία",
    "Disable" : "Απενεργοποίηση",
    "Enable" : "Ενεργοποίηση",
    "Choose" : "Επιλογή",
    "The file must be a PNG or JPG" : "Το αρχείο πρέπει να είναι τύπου PNG ή JPG",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Οι συμμετέχοντες έχουν δικαιώματα για έναρξη κλήσης, συμμετοχή σε κλήση, ενεργοποίηση ήχου και βίντεο και κοινή χρήση οθόνης.",
    "Restricted" : "Περιορισμένο",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Οι συμμετέχοντες μπορούν να συμμετέχουν σε κλήσεις, αλλά δεν μπορούν να ενεργοποιήσουν τον ήχο ή το βίντεο ούτε να μοιραστούν την οθόνη έως ότου ένας συντονιστής τους εκχωρήσει αυτά τα δικαιώματα.",
    "Advanced permissions" : "Προσαρμοσμένα δικαιώματα",
    "Meeting" : "Συνάντηση",
    "Conversation settings" : "Ρυθμίσεις συνομιλίας",
    "Personal" : "Προσωπικός",
    "Matterbridge" : "Matterbridge",
    "Danger zone" : "Επικίνδυνη ζώνη",
    "Do you really want to delete \"{displayName}\"?" : "Θέλετε σίγουρα να διαγράψετε το  \"{displayName}\"?",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Θέλετε πραγματικά να διαγράψετε όλα τα μηνύματα στο \"{displayName}\"?",
    "Be careful, these actions cannot be undone." : "Προσέξτε, αυτές οι ενέργειες δεν μπορούν να αναιρεθούν.",
    "Leave conversation" : "Εγκατάλειψη συνομιλίας",
    "Delete conversation" : "Διαγραφή συνομιλίας",
    "Permanently delete this conversation." : "Οριστική διαγραφή αυτής της συνομιλίας.",
    "Permanently delete all the messages in this conversation." : "Οριστική διαγραφή όλων των μηνυμάτων σε αυτήν τη συνομιλία.",
    "Password protection" : "Προστασία συνθηματικού",
    "Set a password" : "Ορισμός συνθηματικού",
    "Save password" : "Αποθήκευση κωδικού πρόσβασης",
    "Resend invitations" : "Επαναποστολή προσκλήσεων",
    "Error occurred when opening or limiting the conversation" : "Συνέβη σφάλμα κατά το άνοιγμα ή τον περιορισμό της συνομιλίας",
    "Start time has been updated" : "Η ώρα έναρξης ενημερώθηκε",
    "Error occurred while updating start time" : "Παρουσιάστηκε σφάλμα κατά την ενημέρωση της ώρας έναρξης",
    "Meeting start time" : "Ώρα έναρξης της συνάντησης",
    "Start time (optional)" : "Ώρα έναρξης (προαιρετικό)",
    "Error occurred when locking the conversation" : "Παρουσιάστηκε σφάλμα κατά το κλείδωμα της συνομιλίας",
    "Error occurred when unlocking the conversation" : "Παρουσιάστηκε σφάλμα κατά το ξεκλείδωμα της συνομιλίας",
    "Lock conversation" : "Κλειδώστε τη συνομιλία",
    "Edit" : "Επεξεργασία",
    "More information" : "Περισσότερες πληροφορίες",
    "Delete" : "Διαγραφή",
    "Add new bridged channel to current conversation" : "Προσθέστε νέο γεφυρωμένο κανάλι στην τρέχουσα συνομιλία",
    "unknown state" : "άγνωστη κατάσταση",
    "running" : "εκτελείται",
    "not running, check Matterbridge log" : "δεν εκτελείται, ελέγξτε το αρχείο καταγραφής Matterbridge",
    "not running" : "δεν εκτελείται",
    "Bridge saved" : "Η σύνδεση αποθηκεύτηκε",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Μπορείτε να συνδέσετε κανάλια από διάφορα άλλα συστήματα άμεσων μηνυμάτων με το Matterbridge.",
    "More info on Matterbridge" : "Περισσότερες πληροφορίες για το Matterbridge",
    "Enable bridge" : "Ενεργοποίηση γέφυρας",
    "Show Matterbridge log" : "Εμφάνιση αρχείου καταγραφής Matterbridge",
    "Log content" : "Περιεχόμενα αρχείου καταγραφής",
    "Notifications" : "Ειδοποιήσεις",
    "Notify about calls in this conversation" : "Να ειδοποιούμαι για κλήσεις σε αυτήν τη συνομιλία",
    "Important conversation" : "Σημαντική συνομιλία",
    "SIP dial-in is now enabled" : "Το SIP dial-in είναι πλέον ενεργοποιημένο",
    "SIP dial-in is now disabled" : "Το SIP dial-in είναι πλέον απενεργοποιημένο",
    "Error occurred when enabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την ενεργοποίηση του SIP dial-in",
    "Error occurred when disabling SIP dial-in" : "Παρουσιάστηκε σφάλμα κατά την απενεργοποίηση του SIP dial-in",
    "Join" : "Συμμετοχή",
    "Error while creating the conversation" : "Σφάλμα κατά τη δημιουργία συνομιλίας",
    "Create a new conversation" : "Δημιουργία νέας συνομιλίας",
    "Join open conversations" : "Συμμετοχή σε ανοικτές συνομιλίες",
    "Create conversation" : "Δημιουργία συνομιλίας",
    "Enter your name" : "Προσθέστε το όνομά σας",
    "Log in" : "Είσοδος",
    "Mark as read" : "Σήμανση ως αναγνωσμένο",
    "Mark as unread" : "επισήμανση ως μή-αναγνωσμένο",
    "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
    "Add to favorites" : "Προσθήκη στα αγαπημένα ",
    "You need to promote a new moderator before you can leave the conversation." : "Πρέπει να προάγεται νέο συντονιστή πρίν αποχωρήσετε από την συνομιλία.",
    "Conversation actions" : "Δράσεις συνομιλιών",
    "Home" : "Σπίτι",
    "Unread" : "Μη αναγνωσμένο",
    "No matches found" : "Δεν βρέθηκαν αντιστοιχίες",
    "An error occurred while performing the search" : "Παρουσιάστηκε σφάλμα κατά την αναζήτηση",
    "Conversation list" : "Λίστα συνομιλιών",
    "Unread messages" : "Μη αναγνωσμένα μηνύματα",
    "Clear filter" : "Εκκαθάριση φίλτρου",
    "Talk settings" : "Ρυθμίσεις ομιλίας",
    "Users" : "Χρήστες",
    "Groups" : "Ομάδες",
    "Open conversations" : "Άνοιγμα συνομιλιών",
    "No search results" : "Κανένα αποτέλεσμα",
    "Users and groups" : "Χρήστες και ομάδες",
    "Other sources" : "Άλλες πηγές",
    "You are currently waiting in the lobby" : "Βρίσκεστε στην αναμονή",
    "Select microphone" : "Επιλογή μικροφώνου",
    "No microphone available" : "Δεν βρέθηκε μικρόφωνο",
    "Select camera" : "Επιλογή κάμερας",
    "No camera available" : "Δεν υπάρχει διαθέσιμη κάμερα",
    "Test" : "Δοκιμή",
    "Devices" : "Συσκευές",
    "No audio" : "Χωρίς ήχο",
    "No camera" : "Χωρίς κάμερα",
    "Calls are not supported in your browser" : "Οι κλήσεις δεν υποστηρίζονται στον περιηγητή σας.",
    "Access to microphone is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο είναι εφικτή μόνο μέσω HTTPS.",
    "Access to microphone was denied" : "Δεν επιτρέπεται η πρόσβαση στο μικρόφωνο",
    "Error while accessing microphone" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο.",
    "Access to camera is only possible with HTTPS" : "Η πρόσβαση στην κάμερα είναι εφικτή μόνο μέσω HTTPS.",
    "The call is being recorded." : "Η κλήση καταγράφεται.",
    "Select a file" : "Επιλογή αρχείου",
    "Invalid path selected" : "Επιλέχθηκε μη έγκυρη διαδρομή",
    "Blur" : "Θόλωμα",
    "Upload" : "Μεταφόρτωση",
    "Files" : "Αρχεία",
    "Message read by everyone who shares their reading status" : "Το μήνυμα διαβάστηκε από όλους όσους μοιράζονται την κατάσταση ανάγνωσής τους",
    "Message sent" : "Το μήνυμα στάλθηκε",
    "Deleting message" : "Γίνεται διαγραφή μηνύματος",
    "Message deleted successfully" : "Το μήνυμα διαγράφηκε με επιτυχία ",
    "Message could not be deleted because it is too old" : "Δεν ήταν δυνατή η διαγραφή του μηνύματος επειδή είναι αρκετά παλιό ",
    "An error occurred while deleting the message" : "Προέκυψε ένα σφάλμα κατά τη διαγραφή του μηνύματος",
    "Later today – {timeLocale}" : "Αργότερα σήμερα – {timeLocale}",
    "Set reminder for later today" : "Ορισμός υπενθύμισης για αργότερα σήμερα",
    "Tomorrow – {timeLocale}" : "Αύριο – {timeLocale}",
    "Set reminder for tomorrow" : "Ορισμός υπενθύμισης για αύριο",
    "This weekend – {timeLocale}" : "Αυτή την εβδομάδα – {timeLocale}",
    "Set reminder for this weekend" : "Ορίστε υπενθύμιση για αυτό το Σαββατοκύριακο",
    "Next week – {timeLocale}" : "Επόμενη εβδομάδα – {timeLocale}",
    "Set reminder for next week" : "Ορίστε υπενθύμιση για την επόμενη εβδομάδα",
    "Reply" : "Απάντηση",
    "Set reminder" : "Προσθήκη υπενθύμισης",
    "Reply privately" : "Απάντηση ιδιωτικά",
    "Edit message" : "Επεξεργασία μηνύματος",
    "Copy message" : "Αντιγραφή μηνύματος",
    "Copy message link" : "Αντιγραφή συνδέσμου μηνύματος",
    "Go to file" : "Μετάβαση στο αρχείο",
    "Forward message" : "Προώθηση μηνύματος",
    "Translate" : "Μετάφραση",
    "Set custom reminder" : "Ορισμός προσαρμοσμένης υπενθύμισης",
    "Choose a conversation to forward the selected message." : "Επιλέξτε μια συνομιλία για να προωθήσετε το επιλεγμένο μήνυμα.",
    "Error while forwarding message" : "Σφάλμα κατά την προώθηση μηνύματος",
    "The message has been forwarded to {selectedConversationName}" : "Το μήνυμα έχει προωθηθεί στο {selectedConversationName}",
    "Dismiss" : "Αποδέσμευση",
    "Go to conversation" : "Μετάβαση στη συνομιλία",
    "Your browser does not support playing audio files" : "Το πρόγραμμα περιήγησής σας δεν υποστηρίζει την αναπαραγωγή αρχείων ήχου",
    "Contact" : "Επικοινωνία",
    "{stack} in {board}" : "{stack} στο {board}",
    "Remove {fileName}" : "Αφαίρεση {fileName}",
    "Sending message" : "Αποστολή μηνύματος",
    "Failed to send the message. Click to try again" : "Αποτυχία αποστολής του μηνύματος. Κάντε κλικ για να δοκιμάσετε ξανά ",
    "Not enough free space to upload file" : "Δεν επαρκεί ο ελεύθερος χώρος για τη μεταφόρτωση του αρχείου",
    "No messages" : "Κανένα μήνυμα",
    "Create a new group conversation" : "Δημιουργία νέας ομαδικής συζήτησης",
    "Add participants" : "Προσθήκη συμμετεχόντων",
    "Enter password" : "Εισάγετε συνθηματικό",
    "This conversation has been locked" : "Αυτή η συνομιλία έχει κλειδωθεί",
    "No permission to post messages in this conversation" : "Δεν επιτρέπεται η δημοσίευση μηνυμάτων σε αυτήν τη συνομιλία",
    "Joining conversation …" : "Συμμετοχή σε συνομιλία…",
    "Send message" : "Αποστολή μηνύματος",
    "File to share" : "Αρχείο για διαμοιρασμό",
    "Add emoji" : "Προσθήκη emoji",
    "Cancel editing" : "Ακύρωση επεξεργασίας",
    "Share from Files" : "Κοινή χρήση από Αρχεία",
    "Share files to the conversation" : "Διαμοιρασμός αρχείων στην συνομιλία",
    "Upload from device" : "Μεταφόρτωση από συσκευή",
    "Create new poll" : "Δημιουργία νέας ψηφοφορίας",
    "Record voice message" : "Εγγραφή φωνητικού μηνύματος",
    "End recording and send" : "Τερματισμός εγγραφής και αποστολή",
    "Dismiss recording" : "Απόρριψη εγγραφής",
    "Error while recording audio" : "Σφάλμα κατά την εγγραφή ήχου",
    "New file" : "Νέο αρχείο",
    "Blank" : "Κενό",
    "Add more files" : "Προσθήκη περισσότερων αρχείων",
    "Send" : "Αποστολή",
    "Start a call" : "Έναρξη κλήσης",
    "Skip the lobby" : "Παράκαμψη του λόμπι",
    "Enable the microphone" : "Ενεργοποίηση μικροφώνου",
    "Enable the camera" : "Ενεργοποίηση κάμερας",
    "Update permissions" : "Ενημέρωση αδειών",
    "Create poll" : "Δημιουργία ψηφοφορίας",
    "Settings" : "Ρυθμίσεις",
    "Anonymous poll" : "Ανώνυμη δημοσκόπηση",
    "Open poll" : "Ανοιχτή δημοσκόπηση",
    "The message has expired or has been deleted" : "Το μήνυμα έχει λήξει ή έχει διαγραφεί",
    "Disable lobby" : "Απενεργοποίηση αίθουσας αναμονής",
    "Settings for participant \"{user}\"" : "Ρυθμίσεις για συμμετέχοντα \"{user}\"",
    "Participant \"{user}\"" : "Συμμετέχων \"{user}\"",
    "moderator" : "συντονιστής",
    "guest" : "Επισκέπτης",
    "Raised their hand" : "Σήκωσαν το χέρι τους",
    "Joined with video" : "Συμμετοχή με βίντεο",
    "Joined via phone" : "Συμμετοχή μέσω τηλεφώνου",
    "Joined with audio" : "Συμμετοχή με ήχο",
    "Remove group and members" : "Αφαίρεση ομάδων και μελών",
    "Remove participant" : "Αφαίρεση συμμετέχοντα",
    "Dial-in PIN" : "Dial-in PIN",
    "Demote from moderator" : "Υποβάθμιση από συντονιστή",
    "Promote to moderator" : "Προαγωγή από συντονιστή",
    "Resend invitation" : "Επαναποστολή πρόσκλησης",
    "Remove" : "Αφαίρεση",
    "Add users or groups" : "Προσθήκη χρηστών ή ομάδων",
    "Add users" : "Προσθήκη χρηστών",
    "Add groups" : "Προσθήκη ομάδων",
    "Add teams" : "Προσθήκη ομάδων",
    "Add other sources" : "Προσθήκη άλλων πηγών",
    "Add emails" : "Προσθήκη emails",
    "Integrations" : "Ενσωματώσεις",
    "Searching …" : "Αναζήτηση ...",
    "Search for more users" : "Αναζήτηση περισσότερων χρηστών",
    "Search or add participants" : "Αναζήτηση ή προσθήκη συμμετεχόντων",
    "An error occurred while adding the participants" : "Παρουσιάστηκε σφάλμα κατά την προσθήκη των συμμετεχόντων",
    "Participants" : "Συμμετέχοντες",
    "Open chat" : "Άνοιγμα συνομιλίας",
    "Chat" : "Συνομιλία",
    "Details" : "Λεπτομέρειες",
    "No results found" : "Δεν βρέθηκαν αποτελέσματα",
    "Load more results" : "Φόρτωση περισσοτέρων αποτελεσμάτων",
    "Projects" : "Projects",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Σύνδεσμος συνομιλίας",
    "Search conversations or users" : "Αναζήτηση συνομιλιών ή χρηστών",
    "Select conversation" : "Επιλέξτε συνομιλία",
    "Display name: {name}" : "Εμφανιζόμενο όνομα: {name}",
    "Choose the folder in which attachments should be saved." : "Επιλέξτε το φάκελο στον οποίο θα αποθηκεύονται τα συνημμένα.",
    "Select location for attachments" : "Επιλέξτε τοποθεσία για τα συνημμένα",
    "Error while setting attachment folder" : "Σφάλμα κατά την ρύθμιση φακέλου συνημμένων",
    "Your privacy setting has been saved" : "Η ρύθμιση απορρήτου σας έχει αποθηκευτεί",
    "Error while setting read status privacy" : "Σφάλμα κατά τον ορισμό απορρήτου κατάστασης ανάγνωσης",
    "Failed to save sounds setting" : "Αποτυχία αποθήκευσης της ρύθμισης ήχων",
    "Sounds setting saved" : "Η ρύθμιση ήχων αποθηκεύτηκε",
    "Error while saving sounds setting" : "Σφάλμα κατά την αποθήκευση της ρύθμισης ήχων",
    "Attachments folder" : "Φάκελος συνημμένων",
    "Appearance" : "Εμφάνιση",
    "Privacy" : "Ιδιωτικότητα",
    "Share my read-status and show the read-status of others" : "Μοίρασε την κατάσταση ανάγνωσής μου και δείξε την κατάσταση ανάγνωσης των άλλων",
    "Sounds" : "Ήχοι",
    "Play sounds when participants join or leave a call" : "Αναπαραγωγή ήχων όταν οι συμμετέχοντες εισέρχονται ή αποχωρούν από μια κλήση",
    "Sounds can currently not be played on iPad and iPhone devices due to technical restrictions by the manufacturer." : "Οι ήχοι δεν μπορούν προς το παρόν να αναπαραχθούν σε συσκευές iPad και iPhone λόγω τεχνικών περιορισμών από τον κατασκευαστή.",
    "Sounds for chat and call notifications can be adjusted in the personal settings." : "Οι ήχοι για τις ειδοποιήσεις συνομιλίας και κλήσεων μπορούν να ρυθμιστούν στις προσωπικές ρυθμίσεις.",
    "Performance" : "Απόδοση",
    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
    "Speed up your Talk experience with these quick shortcuts." : "Επιταχύνετε την εμπειρία σας στο Talk με αυτές τις γρήγορες συντομεύσεις.",
    "Focus the chat input" : "Εστίασε την είσοδο συνομιλίας",
    "Unfocus the chat input to use shortcuts" : "Αποεπιλέξτε την είσοδο συνομιλίας για να χρησιμοποιήσετε συντομεύσεις",
    "Fullscreen the chat or call" : "Πλήρης οθόνη της συνομιλίας ή της κλήσης",
    "Search" : "Αναζήτηση",
    "Shortcuts while in a call" : "Συντομεύσεις κατά τη διάρκεια μιας κλήσης",
    "Microphone on and off" : "Ενεργοποίηση και απενεργοποίηση μικροφώνου",
    "Space bar" : "Space",
    "Push to talk or push to mute" : "Πιέστε για να μιλήσετε ή πιέστε για σίγαση",
    "Raise or lower hand" : "Σηκώστε ή κατεβάστε το χέρι",
    "More actions" : "Περισσότερες ενέργειες",
    "Start call" : "Έναρξη κλήσης",
    "End call" : "Τερματισμός κλήσης",
    "You will be able to join the call only after a moderator starts it." : "Μπορείτε να συμμετάσχετε στην κλήση μόνο μετά την εκκίνηση από τον συντονιστή.",
    "Recording" : "Καταγραφή",
    "You are not allowed to enable screensharing" : "Δεν επιτρέπεται να ενεργοποιήσετε τον διαμοιρασμό οθόνης",
    "Screensharing options" : "Επιλογές διαμοιρασμού οθόνης",
    "Enable screensharing" : "Ενεργοποίηση διαμοιρασμού οθόνης",
    "Bad sent video and screen quality." : "Κακή ποιότητα βίντεο και διαμοιρασμού οθόνης.",
    "Bad sent screen quality." : "Κακή ποιότητα διαμοιρασμού οθόνης.",
    "Bad sent video quality." : "Κακή ποιότητα βίντεο.",
    "Bad sent audio, video and screen quality." : "Κακή ποιότητα ήχου, βίντεο και διαμοιρασμού οθόνης.",
    "Bad sent audio and screen quality." : "Κακή ποιότητα ήχου και διαμοιρασμού οθόνης.",
    "Bad sent audio and video quality." : "Κακή ποιότητα ήχου και βίντεο.",
    "Bad sent audio quality." : "Κακή ποιότητα ήχου.",
    "Disable background blur" : "Απενεργοποίηση θολώματος φόντου",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να δουν την οθόνη σας.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας δουν.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας ενώ κάνετε κοινή χρήση οθόνης.",
    "Disable screenshare" : "Απενεργοποίηση του διαμοιρασμού οθόνης",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένος και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν και να σας δουν. Για να βελτιώσετε την κατάσταση προσπαθήστε να απενεργοποιήσετε το βίντεό σας.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Η σύνδεση στο Διαδίκτυο ή ο υπολογιστής σας είναι απασχολημένοι και άλλοι συμμετέχοντες ενδέχεται να μην μπορούν να σας καταλάβουν.",
    "Screen sharing is not supported by your browser." : "Η κοινή χρήση οθόνης δεν υποστηρίζεται από τον φυλλομετρητή σας.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η χρήση σελίδας με HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Για τον διαμοιρασμό οθόνης απαιτείται η φόρτωση της σελίδας μέσω HTTPS.",
    "An error occurred while starting screensharing." : "Προυσιάστηκε σφάλμα κατά την έναρξη του διαμοιρασμού οθόνης.",
    "Show your screen" : "Εμφάνιση της οθόνης σας",
    "Stop screensharing" : "Διακόψτε την κοινή χρήση της οθόνης",
    "Mute others" : "Σίγαση των άλλων",
    "Start recording" : "Έναρξη εγγραφής",
    "Select a region" : "Επιλογή περιοχής",
    "Submit" : "Υποβολή",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Message without mention" : "Μήνυμα χωρίς αναφορά σε κάποιον",
    "Mention myself" : "Αναφορά στον εαυτό μου",
    "The conversation does not exist" : "Η συνομιλία δεν υπάρχει",
    "Join a conversation or start a new one!" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα!",
    "Duplicate session" : "Αντιγραφή συνεδρίας",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Συμμετείχατε στη συνομιλία σε άλλο παράθυρο ή συσκευή. Αυτήν τη στιγμή δεν υποστηρίζεται από το Nextcloud Talk, επομένως αυτή η συνεδρία τερματίστηκε.",
    "Join a conversation or start a new one" : "Συμμετέχετε σε συνομιλία ή ξεκινήστε μια νέα",
    "Nextcloud URL" : "Διεύθυνση URL του Nextcloud",
    "Nextcloud user" : "Χρήστης του Nextcloud",
    "User password" : "Συνθηματικό χρήστη",
    "Talk conversation" : "Συνομιλία στο Talk",
    "Skip TLS verification" : "Παράλειψη επαλήθευσης TLS",
    "Matrix server URL" : "Διεύθυνση URL διακομιστή Matrix",
    "User" : "Χρήστης",
    "Matrix channel" : "Κανάλι Matrix",
    "Mattermost server URL" : "Διεύθυνση URL διακομιστή Mattermost",
    "Mattermost user" : "Χρήστης Mattermost",
    "Team name" : "Όνομα ομάδας",
    "Channel name" : "Όνομα καναλιού",
    "Rocket.Chat server URL" : "Διεύθυνση URL διακομιστή Rocket.Chat",
    "User name or email address" : "Όνομα χρήστη ή διεύθυνση email",
    "Password" : "Συνθηματικό",
    "Rocket.Chat channel" : "Κανάλι Rocket.Chat",
    "Zulip server URL" : "Διεύθυνση URL διακομιστή Zulip",
    "Bot user name" : "Όνομα χρήστη του ρομπότ",
    "Bot API key" : "Κλειδί API του ρομπότ",
    "Zulip channel" : "Κανάλι Zulip",
    "API token" : "Διακριτικό API",
    "Slack channel" : "Κανάλι Slack",
    "Server ID or name" : "Όνομα ή ταυτότητα διακομιστή",
    "Channel" : "Κανάλι",
    "Login" : "Είσοδος",
    "Chat ID" : "Αναγνωριστικό συνομιλίας",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "URL διακομιστή IRC (πχ chat.freenode.net:6667)",
    "Nickname" : "Παρατσούκλι",
    "Connection password" : "Κωδικός πρόσβασης σύνδεσης",
    "IRC channel" : "Κανάλι IRC",
    "Channel password" : "Κωδικός πρόσβασης καναλιού",
    "NickServ nickname" : "Ψευδώνυμο NickServ",
    "NickServ password" : "Κωδικός πρόσβασης NickServ",
    "Use TLS" : "Χρήση TLS",
    "Use SASL" : "Χρήση SASL",
    "Tenant ID" : "Ταυτότητα Tenant",
    "Client ID" : "ID πελάτη",
    "Team ID" : "Ταυτότητα ομάδας",
    "Thread ID" : "Thread ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber διακομιστής URL",
    "MUC server URL" : "Διεύθυνση URL διακομιστή MUC",
    "Jabber ID" : "Ταυτότητα Jabber",
    "Media" : "Μέσα ενημέρωσης",
    "Polls" : "Δημοσκοπήσεις",
    "Deck cards" : "Καρτέλες Deck",
    "Voice messages" : "Φωνητικά μηνύματα",
    "Locations" : "Τοποθεσίες",
    "Audio" : "Ήχος",
    "Other" : "Άλλο",
    "Show all files" : "Εμφάνιση όλων των αρχείων",
    "Default" : "Προεπιλεγμένο",
    "Group" : "Ομάδα",
    "You: {lastMessage}" : "Εσείς: {lastMessage}",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Προσπαθείτε να συμμετάσχετε σε μια συνομιλία ενώ έχετε ενεργή συνεδρία σε άλλο παράθυρο ή συσκευή. Αυτή τη στιγμή δεν υποστηρίζεται αυτό από το Nextcloud Talk. Τι θέλετε να κάνετε;",
    "Leave this page" : "Αποχώρηση από την σελίδα",
    "Join here" : "Συμμετέχετε εδώ",
    "Error occurred while allowing guests" : "Παρουσιάστηκε σφάλμα κατά την άδεια των επισκεπτών",
    "Error occurred while disallowing guests" : "Παρουσιάστηκε σφάλμα κατά την απαγόρευση των επισκεπτών",
    "Error occurred when restricting the conversation to moderator" : "Παρουσιάστηκε σφάλμα κατά τον περιορισμό της συνομιλίας σε επόπτη",
    "Error occurred when opening the conversation to everyone" : "Παρουσιάστηκε σφάλμα κατά το άνοιγμα της συνομιλίας σε όλους",
    "Conversation password has been saved" : "Ο κωδικός πρόσβασης συνομιλίας έχει αποθηκευτεί",
    "Conversation password has been removed" : "Ο κωδικός πρόσβασης συνομιλίας έχει αφαιρεθεί",
    "Error occurred while saving conversation password" : "Παρουσιάστηκε σφάλμα κατά την αποθήκευση του κωδικού πρόσβασης συνομιλίας",
    "Call recording stopped. You will be notified once the recording is available." : "Η εγγραφή κλήσης σταμάτησε. Θα ειδοποιηθείτε μόλις η εγγραφή είναι διαθέσιμη.",
    "Error while uploading file \"{fileName}\"" : "Σφάλμα κατά την μεταφόρτωση του αρχείου \"{fileName}\"",
    "Not enough free space to upload file \"{fileName}\"" : "Δεν επαρκεί ο ελεύθερος χώρος για τη μεταφόρτωση του αρχείου \"{fileName}\"",
    "Error while sharing file" : "Σφάλμα κατά τον διαμοιρασμό αρχείου",
    "Could not post message: {errorMessage}" : "Δεν ήταν δυνατή η δημοσίευση μηνύματος: {errorMessage}",
    "An error occurred while fetching the participants" : "Παρουσιάστηκε σφάλμα κατά την ανάκτηση των συμμετεχόντων",
    "Invitations sent" : "Η προσκλήσεις στάλθηκαν",
    "Error occurred when sending invitations" : "Παρουσιάστηκε σφάλμα κατά την αποστολή προσκλήσεων",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Ο περιηγητής που χρησιμοποιείτε δεν υποστηρίζεται πλήρως από το Nextcloud Talk. Παρακαλώ χρησιμοποιήστε την τελευταία έκδοση του Mozilla Firefox, Microsoft Edge, Google Chrome ή Apple Safari.",
    "Lost connection to signaling server. Trying to reconnect." : "Χάθηκε η σύνδεση με τον διακομιστή σηματοδοσίας. Προσπάθεια επανασύνδεσης.",
    "Establishing signaling connection is taking longer than expected …" : "Η διαδικασία σύνδεσης διαρκεί περισσότερο από το αναμενόμενο ...",
    "Failed to establish signaling connection. Retrying …" : "Η διαδικασία σύνδεσης απέτυχε. Προσπάθεια ξανά ...",
    "Please reload the page." : "Παρακαλούμε φορτώστε ξανά τη σελίδα.",
    "Do not disturb" : "Μην ενοχλείτε",
    "Away" : "Λείπω",
    "Microphone {number}" : "Μικρόφωνο {number}",
    "Camera {number}" : "Κάμερα {number}",
    "Speaker {number}" : "Speaker {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Φαίνεται ότι μιλάτε ενώ είστε σε σίγαση, παρακαλώ ενεργοποιήστε τον ήχο σας για να ακουστείτε",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Δεν μπορεί να αποκατασταθεί η σύνδεση με τουλάχιστον ένα συμμετέχοντα. Ένας διακομιστής TURN ίσως απαιτείται για την περίπτωσή σας. Παρακαλώ ρωτήστε τον διαχειριστή σας για εγκατάσταση από τα ακόλουθα  {linkstart}τεκμηρίωση{linkstart}",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Διαρκεί περισσότερο από το αναμενόμενο. Τα δικαιώματα των μέσων επικοινωνίας έχουν χορηγηθεί (ή απορριφθεί); Εάν ναι, κάντε επανεκκίνηση του προγράμματος περιήγησής σας, λόγω αποτυχιας του ήχου και του βίντεο",
    "Access to microphone & camera is only possible with HTTPS" : "Η πρόσβαση στο μικρόφωνο και στην κάμερα είναι εφικτή μόνο μέσω HTTPS",
    "Please move your setup to HTTPS" : "Παρακαλώ μεταφέρεται την εγκατάσταση σας σε HTTPS",
    "Access to microphone & camera was denied" : "Άρνηση πρόσβασης στο μικρόφωνο & την κάμερα",
    "WebRTC is not supported in your browser" : "Το WebRTC δεν υποστηρίζεται από τον φυλλομετρητή σας",
    "Please use a different browser like Firefox or Chrome" : "Παρακαλούμε χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή Chrome",
    "Error while accessing microphone & camera" : "Σφάλμα κατά την πρόσβαση στο μικρόφωνο & την κάμερα",
    "The password is wrong. Try again." : "Το συνθηματικό είναι λανθασμένο. Δοκιμάστε ξανά.",
    "%s Talk on your mobile devices" : "%s Talk στις κινητές συσκευές σας",
    "Join conversations at any time, anywhere, on any device." : "Συμμετέχετε σε συνομιλίες πάντα και παντού από όλες τις συσκευές.",
    "Android app" : "Εφαρμογή Android",
    "iOS app" : "Εφαρμογή iOS",
    "__language_name__" : "Ελληνικά",
    "Tasks" : "Εργασίες",
    "Notes" : "Σημειώσεις",
    "Reports" : "Αναφορές",
    "%s invited you to a conversation." : "%sσας προσκάλεσε σε συζήτηση.",
    "You were invited to a conversation." : "Προσκληθήκατε σε συζήτηση",
    "Click the button below to join." : "Πατήστε το κουμπί παρακάτω για συμμετοχή.",
    "Join »%s«" : "Συμμετοχή »%s«",
    "{user} invited you to a private conversation" : "Ο {user} σας προσκάλεσε σε προσωπική συζήτηση",
    "Always show the device preview screen before joining a call in this conversation." : "Να εμφανίζεται πάντα η οθόνη προεπισκόπησης της συσκευής πριν συμμετάσχετε σε μια κλήση σε αυτήν τη συνομιλία.",
    "Copy conversation link" : "Αντιγραφή συνδέσμου συνομιλίας",
    "Today" : "Σήμερα",
    "Yesterday" : "Χθες",
    "_%n day ago_::_%n days ago_" : ["%n ημέρα πριν","%n ημέρες πριν"],
    "Close" : "Κλείσιμο",
    "Choose devices" : "Επιλέξτε συσκευές",
    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα πριν την έναρξη ή συμμετοχή σε μια κλήση.",
    "Blur background" : "Θόλωμα φόντου",
    "Sharing your screen only works with Firefox version 52 or newer." : "Η κοινή χρήση της οθόνης σας λειτουργεί μόνο με την έκδοση Firefox 52 ή νεότερη.",
    "Screensharing extension is required to share your screen." : "Το πρόσθετο διαμοιρασμού οθόνης απαιτείται για να διαμοιράσετε την οθόνη σας.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Παρακαλώ χρησιμοποιήστε διαφορετικό φυλλομετρητή όπως ο Firefox ή ο Chrome για να διαμοιάσετε την οθόνη σας.",
    "Nextcloud Talk was updated, please reload the page" : "Το Nextcloud Talk ενημερώθηκε, ανανεώστε τη σελίδα",
    "Failed to join the conversation. Try to reload the page." : "Η συμμετοχή στη συνομιλία απέτυχε. Προσπαθήστε να φορτώσετε ξανά τη σελίδα.",
    "Nextcloud is in maintenance mode, please reload the page" : "Το Nextcloud βρίσκεται σε λειτουργία συντήρησης, ανανεώστε τη σελίδα",
    "Lost connection to signaling server. Try to reload the page manually." : "Χάθηκε η σύνδεση με τον διακομιστή σηματοδοσίας. Προσπαθήστε να ανανεώσετε την σελίδα χειροκίνητα."
},
"nplurals=2; plural=(n != 1);");
